@@ -16,7 +16,8 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-import gtk, GDK
+import gtk
+import GDK
 import re, string
 
 class GtkXmHTML(gtk.GtkScrolledWindow):
