@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,38 +15,67 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-
+"""
+>>> d1=Duration(4, 0, Rat(1, 1))
+>>> d2=Duration(4, 1, Rat(1, 1))
+>>> d1==d2
+0
+>>> d1.get_rat_value()
+(Rat 1/4)
+>>> d2.get_rat_value()
+(Rat 3/8)
+>>> d3=Duration(4, 2, Rat(2, 3))
+>>> d3.get_rat_value()
+(Rat 7/24)
+"""
 if __name__ == "__main__":
     import sys, os
     if os.path.isdir("soundcard"):
         sys.path.append(".")
     else:
         sys.path.append("..")
-    
+
 from soundcard.rat import Rat
 
 class Duration:
-    def __init__(self, nh, dots):
+    def __init__(self, nh, dots, tuple=Rat(1, 1)):
         self.m_nh = nh
         self.m_dots = dots
-    def get_undotted_value(self):
-        return self.m_nh
+        self.m_tuple = tuple
+    def __cmp__(self, B):
+        """
+        >>> A=Duration(4, 1, Rat(1, 1))
+        >>> B=Duration(4, 1, Rat(1, 1))
+        >>> C=Duration(2, 2, Rat(4, 7))
+        >>> A==None, A==B, A==C
+        (0, 1, 0)
+        >>> (cmp(A, C), cmp(A, B))
+        (-1, 0)
+        """
+        if not B:
+            return -1
+        return cmp(self.get_rat_value(), B.get_rat_value())
     def get_rat_value(self):
+        """
+        >>> A=Duration(4, 1, Rat(1, 1))
+        >>> B=Duration(4, 2, Rat(3, 5))
+        >>> A.get_rat_value(), B.get_rat_value()
+        ((Rat 3/8), (Rat 21/80))
+        """
         d = Rat(1, self.m_nh)
         if self.m_dots > 0:
             d = d + Rat(1, self.m_nh * 2)
         if self.m_dots > 1:
             d = d + Rat(1, self.m_nh * 4)
-        return d
+        return d * self.m_tuple
+    def clone(self):
+        return Duration(self.m_nh, self.m_dots, self.m_tuple)
     def __str__(self):
-        return "(Duration:%s:%idot)" % (self.m_nh, self.m_dots)
+        return "(Duration:%s:%idot:%s)" % (self.m_nh, self.m_dots, self.m_tuple)
+
+def _test():
+    import doctest, duration
+    return doctest.testmod(duration)
 
 if __name__ == "__main__":
-    def f(h, d):
-        d = Duration(h, d)
-        print d, d.__dict__, d.get_undotted_value(), d.get_rat_value()
-    f(4, 0)
-    f(2, 0)
-    f(4, 1)
-    f(4, 2)
-
+    _test()
