@@ -46,18 +46,10 @@ class dim20:
 
 dimentions = {20: dim20}
 
-#_engraver_count = 0
 class Engraver:
-#    def __del__(self):
-        #global _engraver_count
-        #_engraver_count = _engraver_count - 1
-        #print "Engraver.__del__", _engraver_count
     def __init__(self, timepos, fontsize):
         self.m_fontsize = 20
         self.m_timepos = timepos
-        #global _engraver_count
-        #_engraver_count = _engraver_count + 1
-        #print "Engraver.__init__", _engraver_count
     def get_pixmap_id(self):
         raise "Abstract base class"
     def get_width(self):
@@ -78,7 +70,7 @@ class ClefEngraver(Engraver):
         return 25
     def engrave(self, w, pixmap, gc, staff_yoffset):
         fn = {'violin': 'G',
-              'treble': 'G', #treble == violin
+              'treble': 'G',
               'subbass': 'F',
               'bass': 'F',
               'baritone': 'C',
@@ -110,7 +102,7 @@ class TimeSignatureEngraver(Engraver):
                 fetadir+'/feta%i-number-%s.xpm' % (self.m_fontsize, n))[0]
             gtk.draw_pixmap(pixmap, gc, xpm, 0, 0,
                     self.m_xpos+x, staff_yoffset-12, -1, -1)
-            x  = x + 10
+            x  += 10
         x = 0
         for idx in range(len(str(self.m_timesig.m_den))):
             n = str(self.m_timesig.m_den)[idx]
@@ -118,7 +110,7 @@ class TimeSignatureEngraver(Engraver):
                 fetadir+'/feta%i-number-%s.xpm' % (self.m_fontsize, n))[0]
             gtk.draw_pixmap(pixmap, gc, xpm, 0, 0,
                     self.m_xpos+x, staff_yoffset+3, -1, -1)
-            x = x + 10
+            x += 10
     def __str__(self):
         return '(TimeSignatureEngraver:%i/%i, xpos:%s)' % (self.m_timesig.m_den,
             self.m_timesig.m_num, self.m_xpos)
@@ -140,8 +132,8 @@ class TieEngraver(Engraver):
         self.m_xpos = self.m_xpos2
     def engrave(self, w, pixmap, gc, staff_yoffset):
         dim = dimentions[self.m_fontsize]
-        self.m_xpos1 = self.m_xpos1 + 3 + (self.m_shift1 + 1) * dim.xshift
-        self.m_xpos2 = self.m_xpos2 - 3 + self.m_shift2 * dim.xshift
+        self.m_xpos1 += 3 + (self.m_shift1 + 1) * dim.xshift
+        self.m_xpos2 += - 3 + self.m_shift2 * dim.xshift
         w = self.m_xpos2 - self.m_xpos1
         h = 8
         gtk.draw_arc(pixmap, gc, gtk.FALSE,
@@ -156,7 +148,7 @@ class AccidentalsEngraver(Engraver):
         def f(v, w=dimentions[fontsize].accidental_widths):
             x = 0
             for a in v:
-                x = x + w[a]
+                x += w[a]
             return x
         self.m_usize = reduce(operator.__add__, map(f, accs.values())) + len(accs)
     def set_xpos(self, dict, tpd):
@@ -182,7 +174,7 @@ class AccidentalsEngraver(Engraver):
                          + dimentions[self.m_fontsize].linespacing*y/2
                          + y_offset[acc],
                         -1, -1)
-                x = x + dimentions[self.m_fontsize].accidental_widths[acc] + 1
+                x += dimentions[self.m_fontsize].accidental_widths[acc] + 1
 
 
 class KeySignatureEngraver(Engraver):
@@ -225,7 +217,7 @@ class KeySignatureEngraver(Engraver):
                      + y_offset[type],
                     -1, -1)
             #FIXME see FIXME msg in .get_width
-            x = x + 10
+            x += 10
 
 
 class NoteheadEngraver(Engraver):
