@@ -16,6 +16,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import gtk
+import GDK
 import soundcard
 import parser
 import engravers
@@ -36,7 +37,7 @@ class MusicDisplayer(gtk.GtkScrolledWindow):
 
         self.add_with_viewport(self.g_d)
         self.g_d.connect("expose_event", self.on_expose_event)
-        self.g_d.add_events(gtk.GDK.EXPOSURE_MASK | gtk.GDK.BUTTON_PRESS_MASK)
+        self.g_d.add_events(GDK.EXPOSURE_MASK | GDK.BUTTON_PRESS_MASK)
         self.g_d.connect("button_press_event", self.on_button_press_event)
 
         self.g_pixmap = None
@@ -57,7 +58,6 @@ class MusicDisplayer(gtk.GtkScrolledWindow):
         v = filter(lambda t, end=end: t < end, tv)
         self.m_fontsize = fontsize
         self.m_engravers = score._generate_engravers(v, fontsize)
-        score.help__del__()
         self._display()
     def display(self, music, fontsize, what_part=const.ALL):
         try:
@@ -70,7 +70,6 @@ class MusicDisplayer(gtk.GtkScrolledWindow):
            self.m_engravers = score.get_engravers(fontsize)
         elif what_part == const.FIRST:
            self.m_engravers = score.get_first_engravers(fontsize)
-        score.help__del__()
 
         self.m_fontsize = fontsize
         self._display()
