@@ -33,6 +33,8 @@ The parser does not care if you have correct number of notes in a bar.
 To get bar lines you have to insert a '|'
 """
 
+import weakref
+
 import string, re
 from duration import Duration
 from musicalpitch import MusicalPitch
@@ -59,16 +61,16 @@ def musicalpitch_relative(first, second):
     n1.m_octave_i = first.m_octave_i
     n2 = MusicalPitch(n1)
     if n1 < first:
-        n2.m_octave_i = n2.m_octave_i + 1
+        n2.m_octave_i += 1
     else:
-        n1.m_octave_i = n1.m_octave_i - 1
+        n1.m_octave_i -= 1
     if n2.steps() - first.steps() < first.steps() - n1.steps():
         # we go  up
-        n2.m_octave_i = n2.m_octave_i + second.m_octave_i
+        n2.m_octave_i += second.m_octave_i
         return n2
     else:
         # we go down
-        n1.m_octave_i = n1.m_octave_i + second.m_octave_i
+        n1.m_octave_i += second.m_octave_i
         return n1
 
 
@@ -114,17 +116,6 @@ class ScoreColObj:
         self.m_rightshift = 0
 
 class Score:
-    def help__del__(self):
-        """
-        This should be called when you are finished with the score object,
-        to avoid memory leaks caused by circular reference.
-        """
-        for staff in self.m_staffs:
-           for v in staff.m_voice_list:
-               v.m_parent_staff = None
-               del v
-           del staff
-        del self.m_staffs
     def __init__(self):
         # m_timeposdict is a dictionary of ScoreColObj objects, one
         # object for each column that has music or rests. The keys
@@ -384,19 +375,19 @@ class Score:
         for timepos in pv:
             xv[timepos] = Dummy()
             xv[timepos].m_clef = p
-            p = p + self.m_timeposdict[timepos].m_clef
+            p += self.m_timeposdict[timepos].m_clef
             xv[timepos].m_keysignature = p
-            p = p + self.m_timeposdict[timepos].m_keysignature
+            p += self.m_timeposdict[timepos].m_keysignature
             xv[timepos].m_barline = p
-            p = p + self.m_timeposdict[timepos].m_barline
+            p += self.m_timeposdict[timepos].m_barline
             xv[timepos].m_timesignature = p
-            p = p + self.m_timeposdict[timepos].m_timesignature
+            p += self.m_timeposdict[timepos].m_timesignature
             xv[timepos].m_accidentals = p
-            p = p + self.m_timeposdict[timepos].m_accidentals
+            p += self.m_timeposdict[timepos].m_accidentals
             if self.m_timeposdict[timepos].m_leftshift:
-                p = p + 10
+                p += 10
             xv[timepos].m_music = p
-            p = p + self.m_timeposdict[timepos].m_music
+            p += self.m_timeposdict[timepos].m_music
         for ev in V:
             for e in ev:
                 #FIXME all engravers should take two arguments, i think...
@@ -469,17 +460,9 @@ class Score:
         return track_list
 
 
-#count_staff = 0
 class Staff:
-#    def __del__(self):
-#        global count_staff
-#        count_staff = count_staff - 1
-#        print "del count_staff", count_staff
     def __init__(self, score):
-#        global count_staff
-#        count_staff = count_staff + 1
-#        print "init count_staff", count_staff
-        self.m_score = score
+        self.w_score = weakref.ref(score)
         self.m_coldict = {}
         self.m_voice_list = []
     def add_voice(self):
@@ -520,8 +503,8 @@ class Staff:
         self.m_coldict[timepos].m_barline = 1
     def add_timesignature(self, t, timepos):
         #self.m_coldict[timepos].m_timesignature = t
-        self.m_score.announce_timepos(timepos)
-        self.m_score.m_timeposdict[timepos].m_timesignature_obj = t
+        self.w_score().announce_timepos(timepos)
+        self.w_score().m_timeposdict[timepos].m_timesignature_obj = t
     def add_keysignature(self, timepos, key):
         self.m_coldict[timepos].m_keysignature = key
     def add_clef(self, timepos, clef):
@@ -529,7 +512,7 @@ class Staff:
     def announce_timepos(self, timepos):
         if not self.m_coldict.has_key(timepos):
             self.m_coldict[timepos] = StaffColObj()
-            self.m_score.announce_timepos(timepos)
+            self.w_score().announce_timepos(timepos)
     def maybe_ledger_lines(self, timepos, ypos):
         if not self.m_coldict.has_key(timepos):
             self.m_coldict[timepos] = StaffColObj()
@@ -541,8 +524,8 @@ class Staff:
 
 class Voice:
     def __init__(self, parent_staff):
-        self.m_parent_staff = parent_staff
         self.m_coldict = {}
+        self.w_parent_staff = weakref.ref(parent_staff)
         self._tmp_tie = {}
         self.m_ties = []
         self.m_beams = []
@@ -571,7 +554,7 @@ class Voice:
     def announce_timepos2(self, timepos):
         if not self.m_coldict.has_key(timepos):
             self.m_coldict[timepos] = VoiceColObj()
-            self.m_parent_staff.announce_timepos(timepos)
+            self.w_parent_staff().announce_timepos(timepos)
     def announce_timepos(self, timepos):
         if not self.m_coldict.has_key(timepos):
             self.m_coldict[timepos] = VoiceColObj()
@@ -579,7 +562,7 @@ class Voice:
                 self.m_coldict[timepos].m_beaminfo = 'continue'
             if self.m_doing_tuplet:
                 self.m_coldict[timepos].m_tupletinfo = 'continue'
-            self.m_parent_staff.announce_timepos(timepos)
+            self.w_parent_staff().announce_timepos(timepos)
     def start_tuplet(self, timepos, times, dir):
         self.m_coldict[timepos].m_tupletinfo = (times.m_den, dir)
         self.m_doing_tuplet = 1
@@ -862,7 +845,7 @@ class Lexer:
     def get(self):
         m = self.re_rest.match(self.m_string, self.m_idx)
         if m:
-            self.m_idx = self.m_idx + len(m.group())
+            self.m_idx += len(m.group())
             notelen = m.group(2)
             if notelen:
                 notelen = int(notelen)
@@ -880,7 +863,7 @@ class Lexer:
 
         m = self.re_skip.match(self.m_string, self.m_idx)
         if m:
-            self.m_idx = self.m_idx + len(m.group())
+            self.m_idx += len(m.group())
             IGN1, skiplen, dots = m.groups()
             if skiplen:
                 skiplen = int(skiplen)
@@ -896,7 +879,7 @@ class Lexer:
             return self.SKIP, retval
         m = self.re_melodic.match(self.m_string, self.m_idx)
         if m:
-            self.m_idx = self.m_idx + len(m.group())
+            self.m_idx += len(m.group())
             notename, IGN1, IGN2, notelen, dots = m.groups()
             numdots = len(dots)
             if notelen:
@@ -914,47 +897,47 @@ class Lexer:
             return self.NOTE, n
         m = self.re_staff.match(self.m_string, self.m_idx)
         if m:
-            self.m_idx = self.m_idx + len(m.group())
+            self.m_idx += len(m.group())
             return self.STAFF, None
         m = self.re_voice.match(self.m_string, self.m_idx)
         if m:
-            self.m_idx = self.m_idx + len(m.group())
+            self.m_idx += len(m.group())
             return self.VOICE, None
         m = self.re_relative.match(self.m_string, self.m_idx)
         if m:
-            self.m_idx = self.m_idx + len(m.group())
+            self.m_idx += len(m.group())
             return self.RELATIVE, MusicalPitch(m.group(1))
         m = self.re_clef.match(self.m_string, self.m_idx)
         if m:
-            self.m_idx = self.m_idx + len(m.group())
+            self.m_idx += len(m.group())
             return self.CLEF, m.group(1)
         m = self.re_stem_updown.match(self.m_string, self.m_idx)
         if m:
-            self.m_idx = self.m_idx + len(m.group())
+            self.m_idx += len(m.group())
             d = [const.UP, const.DOWN, const.BOTH][['Up', 'Down', 'Both'].index(m.group(2))]
             return self.STEMDIR, d
         m = self.re_tuplet_updown.match(self.m_string, self.m_idx)
         if m:
-            self.m_idx = self.m_idx + len(m.group())
+            self.m_idx += len(m.group())
             d = [const.UP, const.DOWN, const.BOTH][['Up', 'Down', 'Both'].index(m.group(2))]
             return self.TUPLETDIR, d
         m = self.re_transpose.match(self.m_string, self.m_idx)
         if m:
-            self.m_idx = self.m_idx + len(m.group())
+            self.m_idx += len(m.group())
             return self.TRANSPOSE, MusicalPitch(m.group(1))
         m = self.re_time.match(self.m_string, self.m_idx)
         if m:
-            self.m_idx = self.m_idx + len(m.group())
+            self.m_idx += len(m.group())
             return self.TIME, TimeSignature(int(m.group(1)), int(m.group(2)))
         m = self.re_key.match(self.m_string, self.m_idx)
         if m:
-            self.m_idx = self.m_idx + len(m.group())
+            self.m_idx += len(m.group())
             return self.KEY, (m.group(1), m.group(2))
         m = self.re_times.match(self.m_string, self.m_idx)
         if m:
-            self.m_idx = self.m_idx + len(m.group())
+            self.m_idx += len(m.group())
             return self.TIMES, Rat(int(m.groups()[0]), int(m.groups()[1]))
         while self.m_string[self.m_idx] in [' ', '\n', '\t']:
-            self.m_idx = self.m_idx + 1
-        self.m_idx = self.m_idx + 1
+            self.m_idx += 1
+        self.m_idx += 1
         return self.m_string[self.m_idx-1], None
