@@ -1,4 +1,4 @@
-#!/usr/bin/env python1.5
+#!/usr/bin/python
 
 # GNU Solfege - eartraining for GNOME
 # Copyright (C) 2000, 2001  Tom Cato Amundsen
@@ -19,11 +19,28 @@
 
 # This script is used to launch Solfege when running
 # it from the source dir without installing.
+
 #from __future__ import nested_scopes
 
+#import gc
+#gc.set_debug(gc.DEBUG_LEAK)
+#gc.disable()
+
 import sys
+
+if sys.version_info < (2, 1):
+    print "Solfege need Python 2.1 or newer. Your python seems to be too old."
+    print "Do not report bugs in Solfege before you upgrade your python interpreter."
+
 import src.configureoutput
 
+import src.rcfile
+src.rcfile.copy_rc14_file()
+import src.cfg
+
+src.cfg.initialise(None, "default.config", "~/.solfegerc%i.%i" %
+  (src.configureoutput.MAJOR_VERSION, src.configureoutput.MINOR_VERSION))
+
 if not src.configureoutput.WITH_GNOME:
     sys.path.insert(0, "gnomeemu")
 
