@@ -20,10 +20,10 @@ import types
 from soundcardexceptions import SoundInitException
 synth = None
 
-def initialise_winsynth(verbose_init=0):
+def initialise_winsynth(synthnum, verbose_init=0):
     import winsynth
     global synth
-    synth = winsynth.WinSynth(verbose_init)
+    synth = winsynth.WinSynth(synthnum, verbose_init)
 
 
 def initialise_external_midiplayer(cmdline, verbose_init=0):
