@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,9 +15,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import os, errno
+import os
 import solfege_c_midi
-from exceptions import *
+from soundcardexceptions import *
 
 class AbstractSynth:
     NUM_CHANNELS = 16
@@ -29,6 +29,7 @@ class AbstractSynth:
         if verbose_init:
             self.print_soundcard_info()
     def open_device(self):
+        # the app will crash if I rmmod awe_awe
         solfege_c_midi.cvar.seqfd = os.open(self.m_device, os.O_WRONLY, 0)
         if not solfege_c_midi.sndctl_seq_reset():
             # we cannot use self.close() because that function will try
