@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,7 +15,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import os
 import rat
 import types
 
@@ -34,10 +33,6 @@ class Track:
             print event
     def __init__(self):
         self.m_v = []
-        #ugh
-        #self.start_note(0, 60, 100)
-        #self.notelen_time(4)
-        #self.stop_note(0, 60, 100)
     def start_note(self, chn, pitch, vel):
         assert 0 <= chn < 16
         self.m_v.append([self.NOTE_ON, chn, int(pitch), vel])
