@@ -20,8 +20,8 @@ import winmidi
 
 class WinSynth:
     NUM_CHANNELS = 16
-    def __init__(self, verbose_init):
-        self.__driver = winmidi.Winmidi()
+    def __init__(self, synthnum, verbose_init):
+        self.__driver = winmidi.Winmidi(synthnum)
         if verbose_init:
             print "Solfege will use Windows multimedia output."
     def close(self):
