@@ -16,6 +16,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import gtk, gnome
+from gtk import GDK
 import gu
 import inputwidgets
 import soundcard, mpd
@@ -291,7 +292,7 @@ class Gui(gtk.GtkVBox, cfg.ConfigUtils):
         print "Ending practise with", self.m_exname
     def on_key_press_event(self, widget, event):
         if (self.g_notebook == None or self.g_notebook.get_current_page() == 0) \
-           and event.type == gtk.GDK.KEY_PRESS:
+           and event.type == GDK.KEY_PRESS:
             for s in self.m_key_bindings.keys():
                 if self.keymatch(event, s):
                     self.m_key_bindings[s]()
@@ -324,14 +325,14 @@ class Gui(gtk.GtkVBox, cfg.ConfigUtils):
         label = gtk.GtkLabel(_("Delay (seconds):"))
         label.show()
         def f(button, spin=spin, label=label):
-            spin.set_sensitive(button.active)
-            label.set_sensitive(button.active)
+            spin.set_sensitive(button.get_active())
+            label.set_sensitive(button.get_active())
         b = gu.nCheckButton(self.m_exname, 'new_question_automatically',
                             _("New question automatically."), callback=f)
         hbox.pack_start(b, gtk.FALSE)
-        label.set_sensitive(b.active)
+        label.set_sensitive(b.get_active())
         hbox.pack_start(label, gtk.FALSE)
-        spin.set_sensitive(b.active)
+        spin.set_sensitive(b.get_active())
         hbox.pack_start(spin, gtk.FALSE)
 
 class IntervallGui(Gui):
