@@ -44,16 +44,15 @@ class SolfegeApp(cfg.ConfigUtils):
         # Solfege can handle.
         #
         # First figure out what file to replace
-        if configureoutput.WITH_GNOME:
-            fn = "~/.gnome/%s" % cfg.app_id
-        else:
-            if sys.platform == "win32":
-                fn = "~/solfegerc%s.%s"
-            else:
-                fn = "~/.solfegerc%s.%s"
-            fn = fn % (configureoutput.MAJOR_VERSION,
-                       configureoutput.MINOR_VERSION)
         if sys.platform == "win32":
+            fn = "~/solfegerc%s.%s"
+        else:
+            fn = "~/.solfegerc%s.%s"
+        fn = fn % (configureoutput.MAJOR_VERSION,
+                   configureoutput.MINOR_VERSION)
+        if sys.platform == "win32":
+            # FIXME this version number has to be updated in sync with
+            # Makefile.in
             ver = "1.1.3"
         else:
             ver = "0.7.34"
@@ -63,23 +62,10 @@ class SolfegeApp(cfg.ConfigUtils):
                 # we are running the program from the source dir
                 # without installing. Also windows users go here.
                 shutil.copyfile("default.config", os.path.expanduser(fn))
-                print "\nSorry, but you have to start Solfege one more time."
-                print "I just installed a new", fn
-                sys.exit(-1)
+                #FIXME use cfg.*
+                cfg.reread_data()
             else:
-                print "Ok, you have upgraded, so I will replace your %s file." % fn
-                print "Don't worry, it's no big loss."
-                cfg.clean_file()
-                cfg.sync()
-                if cfg.get_string("app/version") != configureoutput.VERSION_STRING:
-                    # we get here if the user installed with a sysconfdir that
-                    # gnome do not know, eg, not in /etc/gnome/config
-                    assert configureoutput.WITH_GNOME
-                    shutil.copyfile("default.config",
-                               os.path.expanduser("~/.gnome/%s" % cfg.app_id))
-                    print "You have to start Solfege once more."
-                    sys.exit(-1)
-
+                cfg.drop_user_config()
         if __main__.rc_copied:
             # some checks if we have upgraded an old rcfile from 1.0.x
             # or 1.1.x 
@@ -111,7 +97,8 @@ class SolfegeApp(cfg.ConfigUtils):
            or cfg.get_string("sound/type") == "fake-synth":
             soundcard.initialise_using_fake_synth('--verbose-sound-init' in self.m_argv)
         elif cfg.get_string("sound/type") == "winsynth":
-            soundcard.initialise_winsynth(verbose_init='--verbose-sound-init' in self.m_argv)
+            soundcard.initialise_winsynth(cfg.get_int("sound/synth_number"),
+                      verbose_init='--verbose-sound-init' in self.m_argv)
         elif cfg.get_string("sound/type") == "external-midiplayer":
             soundcard.initialise_external_midiplayer(
                     cfg.get_string("sound/commandline"),
