@@ -299,8 +299,12 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
         vbox.pack_start(self.g_fakesynth_radio, gtk.FALSE)
         hbox = gu.bHBox(vbox, gtk.FALSE)
         self.g_device_radio = gu.RadioButton(self.g_fakesynth_radio,
-              _("Windows multimedia output"), None)
+              _("Windows multimedia output, synth number:"), None)
+        self.g_synth_num = gtk.GtkSpinButton(gtk.GtkAdjustment(0, 0, 100, 1, 1),
+                             digits=0)
+        self.g_synth_num.set_value(self.get_int('sound/synth_number'))
         hbox.pack_start(self.g_device_radio, gtk.FALSE)
+        hbox.pack_start(self.g_synth_num, gtk.FALSE)
 
         hbox = gu.bHBox(vbox, gtk.FALSE)
         self.g_midiplayer_radio = gu.RadioButton(self.g_fakesynth_radio,
@@ -324,6 +328,7 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
 
         self.g_fakesynth_radio.connect('clicked', self.on_changed)
         self.g_midiplayer_radio.connect('clicked', self.on_changed)
+        self.g_synth_num.connect('changed', self.on_changed)
         self.g_device_radio.connect('clicked', self.on_changed)
         self.g_midiplayer_entry.connect('changed', self.on_changed)
     def on_sound_test(self, w):
@@ -427,7 +432,7 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
                      card_info = ""
                 try:
                     if sys.platform == 'win32':
-                        soundcard.initialise_winsynth()
+                        soundcard.initialise_winsynth(self.g_synth_num.get_value_as_int())
                     else:
                         soundcard.initialise_devicefile(
                             self.g_device_entry.get_text(),
