@@ -16,6 +16,8 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 from i18n import _, _i
+
+import gtk
 import GDK
 
 SHORT_WAIT = 700
@@ -32,7 +34,7 @@ USE_SING_CHORD = 'sing-chord'
 # The list should have another name. Also, if the number of exercises
 # increase, it should be configurable what exercises are available
 # from the toolbar.
-exercises = ['chord',
+exercises = ('chord',
              'harmonic-intervall',
              'melodic-intervall',
              'sing-intervall',
@@ -43,7 +45,7 @@ exercises = ['chord',
              'id-tone',
              'compare-intervalls',
              'sing-chord',
-             'rhythm']
+             'rhythm')
 
 exercisedata = {
    # id: prettyname, menulabel, pixmap
@@ -78,17 +80,17 @@ QSTATUS_WRONG = 2
 QSTATUS_SOLVED = 3
 QSTATUS_GIVE_UP = 4
 
-int_intervall = [_("unison"), _("minor second"), _("major second"),
+int_intervall = (_("unison"), _("minor second"), _("major second"),
                  _("minor third"), _("major third"), _("fourth"),
                  _("diminished fifth"), _("perfect fifth"),
                  _("minor sixth"), _("major sixth"),
                  _("minor seventh"), _("major seventh"),
                  _("perfect octave"),
                  _("minor ninth"), _("major ninth"),
-                 _("minor decim"), _("major decim")]
+                 _("minor decim"), _("major decim"))
 
-short_intervall_name = [_i("u"), _i("m2"), _i("M2"), _i("m3"), _i("M3"), _i("4"),
+short_intervall_name = (_i("u"), _i("m2"), _i("M2"), _i("m3"), _i("M3"), _i("4"),
                         _i("d5"), _i("5"), _i("m6"), _i("M6"), _i("m7"),
                         _i("M7"), _i("8"), _i("m9"), _i("M9"), _i("m10"),
-                        _i("M10")]
+                        _i("M10"))
 
