@@ -115,54 +115,54 @@ class Dataparser:
             # regular expression
             if s[p] in " \n\t{=}%+,/":
                 if s[p] == ' ':
-                    p = p + 1
+                    p += 1
                     continue
                 if s[p] == '\n':
-                    p = p + 1
-                    linecount = linecount + 1
+                    p += 1
+                    linecount += 1
                     continue
                 if s[p] == '\t':
-                    p = p + 1
+                    p += 1
                     continue
                 if s[p] == '{':
-                    p = p + 1
+                    p += 1
                     v.append((LBRACE, '{', filename, linecount))
                     continue
                 elif s[p] == '=':
-                    p = p + 1
+                    p += 1
                     v.append((EQUALS, '=', filename, linecount))
                     continue
                 elif s[p] == '}':
-                    p = p + 1
+                    p += 1
                     v.append((RBRACE, '}', filename, linecount))
                     if first_block_only:
                         break
                     continue
                 elif s[p] == '%':
-                    p = p + 1
+                    p += 1
                     v.append((PERCENT, '%', filename, linecount))
                     continue
                 elif s[p] == '+':
-                    p = p + 1
+                    p += 1
                     v.append((PLUS, '+', filename, linecount))
                     continue
                 elif s[p] == ',':
-                    p = p + 1
+                    p += 1
                     v.append((COMMA, ',', filename, linecount))
                     continue
                 elif s[p] == '/':
-                    p = p + 1
+                    p += 1
                     v.append((DIVIDE, '/', filename, linecount))
                     continue
             m = re_ALL.match(s[p:])
             if m:
                 if m.group('integer'):
-                    p = p + m.end()
+                    p += m.end()
                     v.append((INTEGER, int(m.group('integer')),
                               filename, linecount))
                     continue
                 if m.group('string'):
-                    p = p + m.end()
+                    p += m.end()
                     linecount = linecount + string.count(m.group(), '\n')
                     if m.group('i18npre'):
                         v.append((I18NSTRING, m.group('string'),
@@ -173,12 +173,12 @@ class Dataparser:
                     continue
                 elif m.group('xstring'):
                     #FIXME can't xstring and string be joined in the regex?
-                    p = p + m.end()
-                    linecount = linecount + string.count(m.group(), '\n')
+                    p += m.end()
+                    linecount += string.count(m.group(), '\n')
                     v.append((STRING, m.group('xstring'), filename, linecount))
                     continue
                 elif m.group('keyword'):
-                    p = p + m.end()
+                    p += m.end()
                     im = re_INCLUDE.match(m.group('keyword'))
                     if im:
                         v.append((INCLUDE, im.groups()[0], filename, linecount))
@@ -186,10 +186,10 @@ class Dataparser:
                         v.append((NAME, m.group('keyword'), filename, linecount))
                     continue
                 elif m.group('comment'):
-                    p = p + m.end()
+                    p += m.end()
                     continue
                 elif m.group('rat_num'):
-                    p = p + m.end()
+                    p += m.end()
                     v.append((TEMPO, (int(m.group('rat_num')),
                                       int(m.group('rat_den')))))
                     continue
@@ -214,7 +214,7 @@ class Dataparser:
             if list[x][0] is op:
                 list[x-1:x+2]=[(s, list[x-1], list[x+1])]
             else:
-                x = x + 1
+                x += 1
         return list
     def do_blockstart(self, list):
         x = 0
@@ -222,7 +222,7 @@ class Dataparser:
             if list[x][0] is NAME and list[x+1][0] is LBRACE:
                 list[x:x+2]=[('BLOCKSTART', list[x])]
             else:
-                x = x + 1
+                x += 1
         return list
     def evaluate(self, exp):
         if exp[0] == DIVIDE_EXP:
@@ -287,15 +287,25 @@ def __f():
        #print p.m_blocks
     print time.clock() - t1
 
+def _benchmark_tokenizer():
+    import time
+    n = 40
+    p = Dataparser()
+    t1 = time.clock()
+    for fn in sys.argv[1:]:
+        if os.path.isfile(fn) and (os.path.basename(fn) != 'Makefile'):
+            for x in range(n):
+                v = p.get_tokens(fn, 0)
+    t2 = time.clock()
+    return t2-t1
 
 if __name__ == "__main__":
     import i18n
     i18n.initialise("share/locale")
     from i18n import _
-
-    #__f()
-    #sys.exit()
-    import profile, pstats
-    profile.run("__f()", "profile.txt")
-    s = pstats.Stats("profile.txt")
-    s.strip_dirs().sort_stats('cumulative').print_stats(100)
+    #print _benchmark_tokenizer()
+    __f()
+    #import profile, pstats
+    #profile.run("__f()", "profile.txt")
+    #s = pstats.Stats("profile.txt")
+    #s.strip_dirs().sort_stats('cumulative').print_stats(100)
