@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,13 +16,15 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import os
+
 import gtk, gnome
 import gu, widgets
 import mpd, mpd.musicdisplayer
-import abstract, const, lessonfile, random
+import abstract, const, lessonfile
 from i18n import _
 from soundcard.rat import Rat
 import soundcard
+import utils
 import configureoutput
 
 class Teacher(abstract.LessonbasedTeacher):
@@ -34,7 +36,7 @@ class Teacher(abstract.LessonbasedTeacher):
         self.q_status = const.QSTATUS_NEW
     def parse_lessonfile(self):
         abstract.LessonbasedTeacher.parse_lessonfile(self)
- 
+
 class Gui(abstract.LessonbasedGui):
     def __init__(self, teacher, window):
         abstract.LessonbasedGui.__init__(self, teacher, window)
@@ -44,7 +46,8 @@ class Gui(abstract.LessonbasedGui):
         # practise_box #
         ################
         self.g_question_title = gu.bLabel(self.practise_box, "")
-        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer()
+
+        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
         self.g_music_displayer.set_usize(-1, 150)
         self.g_music_displayer.show()
         self.practise_box.pack_start(self.g_music_displayer)
@@ -89,7 +92,7 @@ class Gui(abstract.LessonbasedGui):
         self.update_gui_after_lessonfile_change()
     def show_answer(self, widget=None):
         if self.m_t.m_P:
-            self.g_music_displayer.display(self.m_t.m_P.get_music(), 
+            self.g_music_displayer.display(self.m_t.m_P.get_music(),
                             self.get_int('config/feta_font_size=20'))
     def _update(self):
         """
@@ -100,7 +103,9 @@ class Gui(abstract.LessonbasedGui):
         self.g_question_title.set_text(self.m_t.m_P.get_name())
         # tmp func used as callback function
         def f(w, start, end, self=self):
-            track = mpd.music_to_track(self.m_t.m_P.get_music(), start, end)
+            track = mpd.music_to_track(self.m_t.m_P.get_music(),
+                       self.get_int('config/preferred_instrument_velocity'),
+                       start, end)
             apply(track.prepend_bpm, self.m_t.m_P.get_tempo())
             track.prepend_patch(0, self.get_int('config/preferred_instrument'))
             soundcard.synth.play_track(track)
