@@ -55,8 +55,8 @@ class nSpinButton(gtk.GtkSpinButton, cfg.ConfigUtils):#FIXME (??what is there to
         self.set_digits(0)
         self.show()
         self.set_value(self.get_float(self.m_name))
-        if self.get_value_as_float() != self.get_float(self.m_name):
-            self.set_float(self.m_name, self.get_value_as_float())
+        if self.get_value() != self.get_float(self.m_name):
+            self.set_float(self.m_name, self.get_value())
         self.connect('changed', self.on_changed)
         self._watch_id = self.add_watch(self.m_name, self._watch_cb)
     def _watch_cb(self, name):
@@ -65,7 +65,7 @@ class nSpinButton(gtk.GtkSpinButton, cfg.ConfigUtils):#FIXME (??what is there to
         gtk.GtkSpinButton.set_value(self, value)
         self.set_float(self.m_name, value)
     def on_changed(self, _o):
-        self.set_float(self.m_name, self.get_value_as_float())
+        self.set_float(self.m_name, self.get_value())
 
 def tSpinButton(table, x1, x2, y1, y2,
                 value, lower, upper, step_incr=1, page_incr=10, callback=None):
@@ -107,7 +107,7 @@ class nCheckButton(gtk.GtkCheckButton, cfg.ConfigUtils):
     def _watch_cb(self, name):
         self.set_active(self.get_bool(name))
     def on_clicked(self, _o):
-        self.set_bool(self.m_name, self.active)
+        self.set_bool(self.m_name, self.get_active())
         if self.m_callback:
             self.m_callback(_o)
  
@@ -146,7 +146,7 @@ class nCombo(gtk.GtkCombo, cfg.ConfigUtils):
         self.show()
     def entry_changed(self, entry):
         self.set_int(self.m_name, self.popdown_strings.index(entry.get_text()))
- 
+
 class PercussionNameCombo(gtk.GtkCombo, cfg.ConfigUtils):
     def __init__(self, exname, name, default):
         gtk.GtkCombo.__init__(self)
