@@ -19,7 +19,6 @@ import gtk, gnome.xmhtml
 import string, re, os
 import pyscript
 import configureoutput
-import cfg
 
 class _HtmlWidgetCommon:
     def on_key_press_event(self, *argv):
@@ -46,6 +45,7 @@ class _HtmlWidgetCommon:
                 fn = os.path.join('online-docs', lang, 'missing-helpfile.html')
                 if os.path.isfile(fn):
                     self.source(open(fn, 'r').read())
+                    break
 
 class GtkHTML(gtk.GtkScrolledWindow, _HtmlWidgetCommon):
     def __init__(self, activate_cb, anchor_track_cb):
@@ -101,11 +101,7 @@ class XmHTML(gtk.GtkEventBox, _HtmlWidgetCommon):
         txt = self.m_pyscript.evaluate(txt)
         self.__html.source(txt)
 
-
-if not configureoutput.WITH_GNOME:
-   cfg.set_string("gui/htmlwidget", "xmhtml")
-
-if cfg.get_string("gui/htmlwidget") == 'gtkhtml':
+if configureoutput.WITH_GTKHTML:
     import gtkhtml
     HtmlWidget = GtkHTML
 else:
