@@ -91,8 +91,6 @@ class Teacher(abstract.Teacher):
         soundcard.synth.play_track(track)
     def spank_me(self):
         soundcard.play_note(0, 4, 9, 71, self.get_int('config/preferred_instrument_velocity'))
-    def end_practise(self):
-        self.q_status = const.QSTATUS_NO
 
 class Gui(abstract.Gui):
     def __init__(self, teacher, window):
@@ -199,6 +197,7 @@ right now. But I can answer questions if needed.""")))
             if s == const.QSTATUS_NO:
                 self.g_flashbar.flash(_("First tone is %s")
                                       % self.m_t.m_question)
+            self.g_flashbar.clear()
             self.m_t.play_question()
         self.set_percentage_label()
     def on_answer_from_user(self, notename):
@@ -231,7 +230,7 @@ right now. But I can answer questions if needed.""")))
                         else:
                             self.m_t.spank_me()
                     else:
-                        if self.get_bool("config/repeat_question_if_wrong_answer"):
+                        if self.get_bool("config/auto_repeat_question_if_wrong_answer"):
                             self.m_t.play_question()
         self.set_percentage_label()
     def give_up(self, _o=None):
@@ -253,7 +252,7 @@ right now. But I can answer questions if needed.""")))
         self.g_new_tone.set_sensitive(gtk.TRUE)
         self.g_repeat.set_sensitive(gtk.FALSE)
         self.g_give_up.set_sensitive(gtk.FALSE)
+        self.m_t.q_status = const.QSTATUS_NO
     def on_end_practise(self):
         if configureoutput.WITH_GNOME:
             self.g_repeat.set_sensitive(gtk.FALSE)
-            self.m_t.end_practise()
