@@ -15,7 +15,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import gtk, GDK, gnome.ui, types
+import gtk, gnome.ui, types
+import GDK
 from i18n import _
 import mpd
 import soundcard
