@@ -15,7 +15,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import gtk, GDK, gnome, soundcard
+import gtk, gnome, soundcard
+import GDK
 from i18n import _
 import gu, os
 import cfg
@@ -156,12 +157,12 @@ class InstrumentConfigurator(gtk.GtkVBox, cfg.ConfigUtils):
         self.g_override_default_instrument_checkbutton.set_active(
                 self.get_bool('override_default_instrument'))
         self.g_instrsel_high.set_sensitive(
-               self.g_override_default_instrument_checkbutton.active)
+               self.g_override_default_instrument_checkbutton.get_active())
         self.g_instrsel_low.set_sensitive(
-               self.g_override_default_instrument_checkbutton.active)
+               self.g_override_default_instrument_checkbutton.get_active())
         if self.g_instrsel_middle:
             self.g_instrsel_middle.set_sensitive(
-               self.g_override_default_instrument_checkbutton.active)
+               self.g_override_default_instrument_checkbutton.get_active())
     def show(self):
         self.show_all()
 
