@@ -15,21 +15,19 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import sys
+from __future__ import nested_scopes
 
+import sys
 if '--inithack' in sys.argv:
     import inithack
     del sys.argv[sys.argv.index('--inithack')]
 
-import src.rcfile
-src.rcfile.copy_rc12_file()
-
 import time, random
 from i18n import _
 import configureoutput
 
 def do_some_cmdline_options(argv):
-        if filter(lambda a, argv=argv: a in argv, ['-h', '--help']):
+        if '-h' in argv or '--help' in argv:
             print """
 GNU Solfege %s
 Type "man solfege" for more details.
@@ -43,7 +41,7 @@ Options:
     """ % configureoutput.VERSION_STRING
             sys.exit()
 
-        if filter(lambda a, argv=argv: a in argv, ['-v', '--version']):
+        if '-v' in argv or '--version' in argv:
             print """GNU Solfege %s
 This is free software. It is covered by the GNU General Public License,
 and you are welcome to change it and/or distribute copies of it under
@@ -53,7 +51,7 @@ Copyright (c) 2000-2001 by Tom Cato Amundsen <tca@gnu.org>
             """ % configureoutput.VERSION_STRING
             sys.exit()
 
-        if filter(lambda a, argv=argv: a in argv, ['-w', '--warranty']):
+        if '-w' in argv or '--warranty' in argv:
             print """GNU Solfege %s
 Copyright (c) 2000-2001 by Tom Cato Amundsen <tca@gnu.org>
 
@@ -109,7 +107,7 @@ class SplashWin(gtk.GtkWindow):
         vbox.pack_start(l)
         self.show_all()
 
-if not filter(lambda a: a in sys.argv, ['--no-splash', '--help', '--usage', '-?']):
+if not filter(lambda a: a in sys.argv, ['--no-splash', '--usage', '-?']):
     splash_win = SplashWin()
     time.sleep(0.1)
     gtk.gdk_flush()
@@ -129,6 +127,8 @@ for a in ('--no-sound', '--verbose-sound-init'):
         del sys.argv[sys.argv.index(a)]
 
 import gnome, gnome.ui
+# FIXME
+from gnome.ui import *
 import GDK, os, const, string
 import app
 from htmlwidget import HtmlWidget
@@ -316,12 +316,11 @@ class MainWin(gnome.ui.GnomeApp, cfg.ConfigUtils):
         else:
             self.g_config_window.show()
     def setup_menubar(self):
-        from gnome.ui import *
         file_menu = []
         for e in const.exercises:
             file_menu.append(
              (APP_UI_ITEM, const.exercisedata[e][0], None,
-              lambda _o, self=self, e=e: self.m_app.handle_href("solfege:practise/"+e),
+              lambda w, e=e: self.m_app.handle_href("solfege:practise/"+e),
               None, APP_PIXMAP_NONE, None,
               const.exercisedata[e][2], const.exercisedata[e][3]))
         file_menu = file_menu + [
@@ -331,30 +330,29 @@ class MainWin(gnome.ui.GnomeApp, cfg.ConfigUtils):
             ]
         help_menu = [
                     (APP_UI_ITEM, _("_Help on current exercise"), None,
-                     lambda w, self=self: self.m_app.please_help_me(), 
+                     lambda w: self.m_app.please_help_me(),
                      None, APP_PIXMAP_NONE, None, GDK.F1, 0),
                     (APP_UI_ITEM, _("Welcome"), None,
-                    lambda f, self=self: self.m_app.handle_href('welcome.html'),
+                    lambda w: self.m_app.handle_href('welcome.html'),
                     None, APP_PIXMAP_NONE, None, 0, 0),
                     (APP_UI_ITEM, _("All help files"), None,
-                    lambda f, self=self: self.m_app.handle_href('index.html'),
+                    lambda w: self.m_app.handle_href('index.html'),
                     None, APP_PIXMAP_NONE, None, 0, 0),
                     (APP_UI_ITEM, _("All installed lesson files"), None,
-                    lambda w, self=self: self.m_app.handle_href('solfege:all-lessonfiles'),
-                    #lambda w, self=self: self.display_html(self.m_app.lessonfile_manager.m_htmldoc),
+                    lambda w: self.m_app.handle_href('solfege:all-lessonfiles'),
                     None, APP_PIXMAP_NONE, None, 0, 0),
                     UIINFO_SEPARATOR,
                     (APP_UI_ITEM, _("Copyright notice"), None,
-                    lambda f, self=self: self.m_app.handle_href('copyright.html'),
+                    lambda w: self.m_app.handle_href('copyright.html'),
                     None, APP_PIXMAP_NONE, None, 0, 0),
                     (APP_UI_ITEM, _("Credits"), None,
-                    lambda f, self=self: self.m_app.handle_href('AUTHORS.html'),
+                    lambda w: self.m_app.handle_href('AUTHORS.html'),
                     None, APP_PIXMAP_NONE, None, 0, 0),
                     (APP_UI_ITEM, _("Mailinglists, web page etc."), None,
-                    lambda f, self=self: self.m_app.handle_href('online-resources.html'),
+                    lambda w: self.m_app.handle_href('online-resources.html'),
                     None, APP_PIXMAP_NONE, None, 0, 0),
                     (APP_UI_ITEM, _("Reporting bugs"), None,
-                    lambda f, self=self: self.m_app.handle_href('bug-reporting.html'),
+                    lambda w: self.m_app.handle_href('bug-reporting.html'),
                     None, APP_PIXMAP_NONE, None, 0, 0),
                     UIINFO_MENU_ABOUT_ITEM(self.show_about_window, None),
                     ]
@@ -363,16 +361,16 @@ class MainWin(gnome.ui.GnomeApp, cfg.ConfigUtils):
              None, None, None, APP_PIXMAP_NONE, None, 0, 0),
              UIINFO_SEPARATOR,
             (APP_UI_ITEM, _("_Tempo"), None,
-             lambda _o, s=self: s.m_app.handle_href('solfege:/identify-bpm'),
+             lambda w: self.m_app.handle_href('solfege:/identify-bpm'),
              None, APP_PIXMAP_NONE, None, 0, 0),
             (APP_UI_ITEM, _("Intervall"), None,
-             lambda _o, s=self: s.m_app.handle_href('solfege:/intervalls'),
+             lambda w: self.m_app.handle_href('solfege:/intervalls'),
              None, APP_PIXMAP_NONE, None, 0, 0),
             (APP_UI_ITEM, _("Rhythm"), None,
-             lambda _o, s=self: s.m_app.handle_href('solfege:/polyrhythm'),
+             lambda w: self.m_app.handle_href('solfege:/polyrhythm'),
              None, APP_PIXMAP_NONE, None, 0, 0),
             (APP_UI_ITEM, const.exercisedata['harmonic-progression-dictation'][0], None,
-             lambda _o, s=self: s.m_app.handle_href('solfege:/harmonic-progression-dictation'),
+             lambda w: self.m_app.handle_href('solfege:/harmonic-progression-dictation'),
              None, APP_PIXMAP_NONE, None, 0, 0),
 
             UIINFO_ITEM_STOCK(_("Experiment"), None,
@@ -381,7 +379,7 @@ class MainWin(gnome.ui.GnomeApp, cfg.ConfigUtils):
         if configureoutput.ENABLE_TUNER:
             development_menu = development_menu + [
             (APP_UI_ITEM, _("Tuner"), None,
-             lambda _o, s=self: s.m_app.handle_href('solfege:/tuner'),
+             lambda w: self.m_app.handle_href('solfege:/tuner'),
              None, APP_PIXMAP_NONE, None, 0, 0)]
         self.m_menuinfo = menu = [
             UIINFO_SUBTREE(_("_File"), file_menu),
@@ -409,23 +407,23 @@ class MainWin(gnome.ui.GnomeApp, cfg.ConfigUtils):
             pix, mask = gtk.create_pixmap_from_xpm(self, None,
                os.path.join('xpm', const.exercisedata[i][1]))
             self.g_toolbar.append_item(n, n, i, gtk.GtkPixmap(pix, mask),
-                    lambda id, self=self, i=i: self.m_app.handle_href("solfege:practise/"+i))
+                    lambda w, i=i: self.m_app.handle_href("solfege:practise/"+i))
         self.add_toolbar(self.g_toolbar, "main-toolbar",
                          gnome.uiconsts.DOCK_ITEM_BEH_NORMAL,
                          gnome.uiconsts.DOCK_TOP, 1, 1, 0)
         self.g_navbar = gtk.GtkToolbar(gtk.ORIENTATION_HORIZONTAL,
                                        gtk.TOOLBAR_ICONS)
-        self.g_navbar.append_item(_("Back"), None, None, 
+        self.g_navbar.append_item(_("Back"), None, None,
             gnome.ui.GnomeStock(gnome.ui.STOCK_PIXMAP_BACK), self.history_back)
-        self.g_navbar.append_item(_("Forward"), None, None, 
-              gnome.ui.GnomeStock(gnome.ui.STOCK_PIXMAP_FORWARD), 
+        self.g_navbar.append_item(_("Forward"), None, None,
+              gnome.ui.GnomeStock(gnome.ui.STOCK_PIXMAP_FORWARD),
                                   self.history_forward)
         self.g_navbar.set_style({'icons': gtk.TOOLBAR_ICONS,
                                  'text': gtk.TOOLBAR_TEXT,
                                  'both': gtk.TOOLBAR_BOTH}
                [self.get_string('gui/navbar_style')])
         self.add_toolbar(self.g_navbar, 'backandforward',
-                         gnome.uiconsts.DOCK_ITEM_BEH_NORMAL, 
+                         gnome.uiconsts.DOCK_ITEM_BEH_NORMAL,
                          gnome.uiconsts.DOCK_TOP, 1, 0, 0)
     def display_in_musicviewer(self, music):
         if not self.g_musicviewer_window:
