@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -102,10 +102,10 @@ class Gui(abstract.IntervallGui):
         self.select_inputwidget()
     def give_up(self, _o=None):
         if self.m_t.q_status == const.QSTATUS_WRONG:
-            s = utils.int_to_intervallname(self.m_t.m_question[0], 
+            s = utils.int_to_intervallname(self.m_t.m_question[0],
                        len(self.m_t.m_question) > 1, 1)
             for n in self.m_t.m_question[1:]:
-                s = s + "+" + utils.int_to_intervallname(n, 
+                s = s + "+" + utils.int_to_intervallname(n,
                        len(self.m_t.m_question) > 1, 1)
             self.g_flashbar.push(_("The answer is: %s") % s)
             self.m_t.give_up()
@@ -175,6 +175,10 @@ class Gui(abstract.IntervallGui):
             self.g_flashbar.clear()
         elif ret == Teacher.ERR_PICKY:
             self.g_flashbar.flash(_("You have to solve this question first."))
+    def on_start_practise(self):
+        self.m_t.m_statistics.reset_session()
+        gtk.timeout_add(const.SHORT_WAIT, lambda self=self:
+            self.g_flashbar.flash(_("Click 'New intervall' to begin.")))
     def on_end_practise(self):
         self.g_new_intervall.set_sensitive(gtk.TRUE)
         self.g_repeat.set_sensitive(gtk.FALSE)
