@@ -15,7 +15,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import gtk, GDK, gnome
+import gtk, gnome
+import GDK
 import mpd, gu, cfg
 import types
 from i18n import _
@@ -42,12 +43,12 @@ class SimplestNotenameSpinButton(gtk.GtkHBox):
         self.pack_start(box, gtk.FALSE, gtk.FALSE)
         eb = gtk.GtkEventBox()
         eb.connect('button_press_event', self.on_arrowclick, 1)
-        self.g_up = gtk.GtkArrow(at=gtk.ARROW_UP)
+        self.g_up = gtk.GtkArrow(gtk.ARROW_UP, gtk.SHADOW_OUT)
         eb.add(self.g_up)
         box.pack_start(eb)
         eb = gtk.GtkEventBox()
         eb.connect('button_press_event', self.on_arrowclick, -1)
-        self.g_down = gtk.GtkArrow(at=gtk.ARROW_DOWN)
+        self.g_down = gtk.GtkArrow(gtk.ARROW_DOWN, gtk.SHADOW_OUT)
         eb.add(self.g_down)
         box.pack_start(eb)
         self.g_entry.connect('event', self.on_entry_event)
