@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000-2001  Tom Cato Amundsen
+# Copyright (C) 2000, 2001  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@ import soundcard, mpd, mpd.musicdisplayer
 import abstract, const
 import statistics, statisticsviewer
 from i18n import _
+import utils
 
 class Teacher(abstract.MelodicIntervallTeacher):
     def __init__(self, exname, app):
@@ -35,7 +36,7 @@ class Teacher(abstract.MelodicIntervallTeacher):
             n.set_from_int(i)
             last = last + n
             s = s + " " + last.str()
-        return self.m_tonika, r"\staff{ \clef %s; %s}" % (mpd.select_clef(s), s)
+        return self.m_tonika, r"\staff{ \clef %s %s}" % (mpd.select_clef(s), s)
     def guessed_correct(self):
         if self.get_int('number_of_intervalls=1') == 1:
             self.m_statistics.add_correct(self.m_question[0])
@@ -43,7 +44,7 @@ class Teacher(abstract.MelodicIntervallTeacher):
     def guessed_wrong(self):
         if self.get_int('number_of_intervalls=1') == 1:
             self.m_statistics.add_wrong(self.m_question[0], None)
-        self.q_status = const.QSTATUS_SOLVED # ugh workaround, just to make it work
+        self.q_status = const.QSTATUS_SOLVED # FIXME workaround, just to make it work
     def play_first_tone(self):
         if self.q_status == const.QSTATUS_NO:
             return
@@ -75,7 +76,7 @@ class Gui(abstract.Gui):
         ################
         # practise_box #
         ################
-        self.g_score_displayer = mpd.musicdisplayer.MusicDisplayer()
+        self.g_score_displayer = mpd.musicdisplayer.MusicDisplayer(utils.play_tone)
         self.practise_box.pack_start(self.g_score_displayer)
         self.g_score_displayer.clear()
         b1 = gu.bHBox(self.practise_box, gtk.FALSE)
@@ -132,6 +133,8 @@ class Gui(abstract.Gui):
             gnome.ui.GnomeErrorDialog(_("The exercise has to be better configured.\nClick 'Reset to default values' on the config\npage if you don't know how to do this."))
             self.g_score_displayer.clear()
         return r
+    def on_start_practise(self):
+        self.m_t.m_statistics.reset_session()
     def on_end_practise(self):
         self.g_new_intervall.show()
         self.g_new_intervall_ok.hide()
