@@ -28,7 +28,8 @@ class HarmonicProgressionLabel(gtk.GtkHBox):
         self.show()
         self.set_text(str, align)
     def set_text(self, str, align=''):
-        self.foreach(lambda o: o.destroy())
+        for o in self.children():
+            o.destroy()
         self.m_str = str
         if align == 'center':
             self.pack_start(gtk.GtkHBox())
