@@ -89,11 +89,13 @@ class PercentagesTable(gtk.GtkFrame):
         self.show_all()
     def clear(self):
         for box in self.boxdict.values():
-            box.foreach(lambda o: o.destroy())
+            for o in box.children():
+                o.destroy()
     def update(self, statistics):
         self.clear()
         for box in self.boxdict.values():
-            box.foreach(lambda o: o.destroy())
+            for o in box.children():
+                o.destroy()
         for k in statistics.get_keys():
             # FIXME  Has this bug been fixed? This should NEVER happen.
             if k == None:
