@@ -15,7 +15,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import GDK, string, re, math
+import gtk
+import GDK
+import string, re, math
 import mpd
 import const
 import random
