@@ -1,20 +1,21 @@
-#!/usr/bin/env python
+#!/usr/bin/python2.1
 import sys, os
+sys.path.append("/usr/lib/python1.5/site-packages")
 if os.path.isdir("soundcard"):
     sys.path.append(".")
 else:
     sys.path.append("..")
 
-import gnome.ui, gnome.config
-gnome.config.push_prefix("Solfege/")
+import gnome.ui
 import mpd, mpd.musicdisplayer, soundcard
 import gtk
-from src import gu
+from src import gu, cfg
+cfg.initialise(None, None, 'mpd-test')
 import src.utils
 
 class DisplaytestWindow(gtk.GtkWindow):
     def on_quit(self, w):
-        gnome.config.sync()
+        cfg.sync()
     def __init__(self):
         gtk.GtkWindow.__init__(self)
         self.connect('destroy', self.on_quit)
@@ -24,7 +25,7 @@ class DisplaytestWindow(gtk.GtkWindow):
         self.g_text = gtk.GtkText()
         self.g_text.show()
         self.g_text.set_editable(gtk.TRUE)
-        s = gnome.config.get_string('config/score_displayer')
+        s = cfg.get_string('config/score_displayer')
         if not s:
             s = r"\staff{c' d' e'}"
         self.g_text.insert_defaults(s)
@@ -36,32 +37,31 @@ class DisplaytestWindow(gtk.GtkWindow):
         gu.bButton(vbox, "Parse", self.on_parse)
         gu.bButton(vbox, "Display", self.on_display)
         gu.bButton(vbox, "Display first notes", self.on_display_first_notes)
-        gu.bButton(vbox, "Display last notes", self.on_display_last_notes)
+        #gu.bButton(vbox, "Display last notes", self.on_display_last_notes)
         gu.bButton(vbox, "Play", self.on_play)
         gu.bButton(vbox, "Play first", self.on_play_first)
     def on_parse(self, _o):
         t = self.g_text.get_chars(0, -1)
         score = mpd.parser.parse_to_score_object(t)
-        score.help__del__()
     def on_display(self, _o):
         t = self.g_text.get_chars(0, -1)
-        gnome.config.set_string('config/score_displayer', t)
+        cfg.set_string('config/score_displayer', t)
         self.g_displayer.display(t, 20)
     def on_display_first_notes(self, _o):
         t = self.g_text.get_chars(0, -1)
-        gnome.config.set_string('config/score_displayer', t)
+        cfg.set_string('config/score_displayer', t)
         self.g_displayer.display(t, 20, mpd.FIRST)
     def on_display_last_notes(self, _o):
         t = self.g_text.get_chars(0, -1)
-        gnome.config.set_string('config/score_displayer', t)
+        cfg.set_string('config/score_displayer', t)
         self.g_displayer.display(t, 20, mpd.LAST)
     def on_play(self, _o):
         t = self.g_text.get_chars(0, -1)
-        gnome.config.set_string('config/score_displayer', t)
-        mpd.play_music(t, (120, 4), 0)
+        cfg.set_string('config/score_displayer', t)
+        mpd.play_music(t, (120, 4), 0, 100)
     def on_play_first(self, _o):
         t = self.g_text.get_chars(0, -1)
-        tr = mpd.music_to_track(t, soundcard.rat.Rat(0, 1), soundcard.rat.Rat(1, 8))
+        tr = mpd.music_to_track(t, 100, soundcard.rat.Rat(0, 1), soundcard.rat.Rat(1, 8))
         soundcard.synth.play_track(tr)
 
 
@@ -72,5 +72,4 @@ soundcard.initialise_devicefile("/dev/music", 0)
 w = DisplaytestWindow()
 w.connect('destroy', gtk.mainquit)
 w.show()
-
 gtk.mainloop()
